dhcpkit\_vpp\.protocols\.layer3\_registry module
================================================

.. automodule:: dhcpkit_vpp.protocols.layer3_registry
    :members:
    :undoc-members:
    :show-inheritance:
